==> freecad_0.19.2+dfsg1.orig.tar.xz: FreeCAD-0.19.2/src/Mod/Web/Gui/Resources/translations/Web_zh-CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh-CN" sourcelanguage="en">
  <context>
    <name>CmdWebBrowserBack</name>
    <message>
      <location filename="../../Command.cpp" line="76"/>
      <source>Web</source>
      <translation>网页</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="77"/>
      <source>Previous page</source>
      <translation>下一页</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="78"/>
      <source>Go back to the previous page</source>
      <translation>返回到上一页</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserNext</name>
    <message>
      <location filename="../../Command.cpp" line="105"/>
      <source>Web</source>
      <translation>网页</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="106"/>
      <source>Next page</source>
      <translation>下页</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="107"/>
      <source>Go to the next page</source>
      <translation>转到下一页</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserRefresh</name>
    <message>
      <location filename="../../Command.cpp" line="134"/>
      <source>Web</source>
      <translation>网页</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="135"/>
      <location filename="../../Command.cpp" line="136"/>
      <source>Refresh web page</source>
      <translation>刷新页面</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserSetURL</name>
    <message>
      <location filename="../../Command.cpp" line="250"/>
      <source>Web</source>
      <translation>网页</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="251"/>
      <location filename="../../Command.cpp" line="252"/>
      <source>Set URL</source>
      <translation>设置链接</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserStop</name>
    <message>
      <location filename="../../Command.cpp" line="162"/>
      <source>Web</source>
      <translation>网页</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="163"/>
      <location filename="../../Command.cpp" line="164"/>
      <source>Stop loading</source>
      <translation>停止加载</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserZoomIn</name>
    <message>
      <location filename="../../Command.cpp" line="192"/>
      <source>Web</source>
      <translation>网页</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="193"/>
      <location filename="../../Command.cpp" line="194"/>
      <source>Zoom in</source>
      <translation>放大</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserZoomOut</name>
    <message>
      <location filename="../../Command.cpp" line="221"/>
      <source>Web</source>
      <translation>网页</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="222"/>
      <location filename="../../Command.cpp" line="223"/>
      <source>Zoom out</source>
      <translation>缩小</translation>
    </message>
  </context>
  <context>
    <name>CmdWebOpenWebsite</name>
    <message>
      <location filename="../../Command.cpp" line="50"/>
      <source>Web</source>
      <translation>网页</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="51"/>
      <source>Open website...</source>
      <translation>打开网站...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="52"/>
      <source>Opens a website in FreeCAD</source>
      <translation>在 FreeCAD 中打开一个网站</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../AppWebGui.cpp" line="88"/>
      <location filename="../../BrowserView.cpp" line="748"/>
      <source>Browser</source>
      <translation>浏览器</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="563"/>
      <source>File does not exist!</source>
      <translation>文件不存在！</translation>
    </message>
  </context>
  <context>
    <name>WebGui::BrowserView</name>
    <message>
      <location filename="../../BrowserView.cpp" line="551"/>
      <location filename="../../BrowserView.cpp" line="556"/>
      <location filename="../../BrowserView.cpp" line="559"/>
      <source>Error</source>
      <translation>错误</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="556"/>
      <source>There were errors while loading the file. Some data might have been modified or not recovered at all. Look in the report view for more specific information about the objects involved.</source>
      <translation>加载文件时出错。有些数据可能已经修改或未全部恢复。在报告视图中查看有关对象的更具体信息。</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="559"/>
      <source>There were serious errors while loading the file. Some data might have been modified or not recovered at all. Saving the project will most likely result in loss of data.</source>
      <translation type="unfinished">There were serious errors while loading the file. Some data might have been modified or not recovered at all. Saving the project will most likely result in loss of data.</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="719"/>
      <source>Loading %1...</source>
      <translation>正在加载 %1...</translation>
    </message>
  </context>
  <context>
    <name>WebGui::WebView</name>
    <message>
      <location filename="../../BrowserView.cpp" line="308"/>
      <source>Open in External Browser</source>
      <translation>在外部浏览器中打开</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="312"/>
      <source>Open in new window</source>
      <translation>在新窗口中打开</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="344"/>
      <source>View source</source>
      <translation>查看来源</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="46"/>
      <source>Navigation</source>
      <translation>导航栏</translation>
    </message>
  </context>
</TS>

==> freecad_0.20.1+dfsg1.orig.tar.xz: FreeCAD-0.20.1/src/Mod/Web/Gui/Resources/translations/Web_zh-CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh-CN" sourcelanguage="en">
  <context>
    <name>CmdWebBrowserBack</name>
    <message>
      <location filename="../../Command.cpp" line="72"/>
      <source>Web</source>
      <translation>网页</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="73"/>
      <source>Previous page</source>
      <translation>下一页</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="74"/>
      <source>Go back to the previous page</source>
      <translation>返回到上一页</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserNext</name>
    <message>
      <location filename="../../Command.cpp" line="101"/>
      <source>Web</source>
      <translation>网页</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="102"/>
      <source>Next page</source>
      <translation>下页</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="103"/>
      <source>Go to the next page</source>
      <translation>转到下一页</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserRefresh</name>
    <message>
      <location filename="../../Command.cpp" line="130"/>
      <source>Web</source>
      <translation>网页</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="131"/>
      <location filename="../../Command.cpp" line="132"/>
      <source>Refresh web page</source>
      <translation>刷新页面</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserSetURL</name>
    <message>
      <location filename="../../Command.cpp" line="246"/>
      <source>Web</source>
      <translation>网页</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="247"/>
      <location filename="../../Command.cpp" line="248"/>
      <source>Set URL</source>
      <translation>设置链接</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserStop</name>
    <message>
      <location filename="../../Command.cpp" line="158"/>
      <source>Web</source>
      <translation>网页</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="159"/>
      <location filename="../../Command.cpp" line="160"/>
      <source>Stop loading</source>
      <translation>停止加载</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserZoomIn</name>
    <message>
      <location filename="../../Command.cpp" line="188"/>
      <source>Web</source>
      <translation>网页</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="189"/>
      <location filename="../../Command.cpp" line="190"/>
      <source>Zoom in</source>
      <translation>放大</translation>
    </message>
  </context>
  <context>
    <name>CmdWebBrowserZoomOut</name>
    <message>
      <location filename="../../Command.cpp" line="217"/>
      <source>Web</source>
      <translation>网页</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="218"/>
      <location filename="../../Command.cpp" line="219"/>
      <source>Zoom out</source>
      <translation>缩小</translation>
    </message>
  </context>
  <context>
    <name>CmdWebOpenWebsite</name>
    <message>
      <location filename="../../Command.cpp" line="46"/>
      <source>Web</source>
      <translation>网页</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="47"/>
      <source>Open website...</source>
      <translation>打开网站...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="48"/>
      <source>Opens a website in FreeCAD</source>
      <translation>在 FreeCAD 中打开一个网站</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../BrowserView.cpp" line="785"/>
      <location filename="../../AppWebGui.cpp" line="85"/>
      <source>Browser</source>
      <translation>浏览器</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="597"/>
      <source>File does not exist!</source>
      <translation>文件不存在！</translation>
    </message>
  </context>
  <context>
    <name>WebGui::BrowserView</name>
    <message>
      <location filename="../../BrowserView.cpp" line="585"/>
      <location filename="../../BrowserView.cpp" line="590"/>
      <location filename="../../BrowserView.cpp" line="593"/>
      <source>Error</source>
      <translation>错误</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="590"/>
      <source>There were errors while loading the file. Some data might have been modified or not recovered at all. Look in the report view for more specific information about the objects involved.</source>
      <translation>加载文件时出错。有些数据可能已经修改或未全部恢复。在报告视图中查看有关对象的更具体信息。</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="593"/>
      <source>There were serious errors while loading the file. Some data might have been modified or not recovered at all. Saving the project will most likely result in loss of data.</source>
      <translation>加载文件时出现严重错误。有些数据可能已被修改或根本没有恢复。 保存项目很可能导致数据丢失。</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="753"/>
      <source>Loading %1...</source>
      <translation>正在加载 %1...</translation>
    </message>
  </context>
  <context>
    <name>WebGui::WebView</name>
    <message>
      <location filename="../../BrowserView.cpp" line="351"/>
      <source>Open in External Browser</source>
      <translation>在外部浏览器中打开</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="355"/>
      <source>Open in new window</source>
      <translation>在新窗口中打开</translation>
    </message>
    <message>
      <location filename="../../BrowserView.cpp" line="387"/>
      <source>View source</source>
      <translation>查看来源</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="37"/>
      <source>Navigation</source>
      <translation>导航栏</translation>
    </message>
  </context>
</TS>
